@@ -4,9 +4,9 @@
 
 """Top-level package for SDV."""
 
-__author__ = """MIT Data To AI Lab"""
-__email__ = 'dailabmit@gmail.com'
-__version__ = '0.17.2'
+__author__ = 'DataCebo, Inc.'
+__email__ = 'info@sdv.dev'
+__version__ = '0.18.0'
 
 from sdv import constraints, evaluation, metadata, relational, tabular
 from sdv.demo import get_available_demos, load_demo
