@@ -4,11 +4,13 @@ import logging
 import sys
 import warnings
 
+import cloudpickle
 import numpy as np
 import rdt
 
 from sdv.metadata import Table
 from sdv.tabular import GaussianCopula
+from sdv.utils import get_package_versions, throw_version_mismatch_warning
 
 LOGGER = logging.getLogger(__name__)
 
@@ -64,9 +66,9 @@ class TabularPreset():
             self._model = GaussianCopula(
                 table_metadata=metadata,
                 constraints=constraints,
-                categorical_transformer='categorical_fuzzy',
+                categorical_transformer='FrequencyEncoder_noised',
                 default_distribution='gaussian',
-                rounding=None,
+                learn_rounding_scheme=False,
             )
 
             # Decide if transformers should model the null column or not.
@@ -76,31 +78,27 @@ class TabularPreset():
 
             # If transformers should model the null column, pass None to let each transformer
             # decide if it's necessary or not.
-            transformer_null_column = None if self._null_column else False
+            transformer_model_missing_values = bool(self._null_column)
 
             dtype_transformers = {
-                'i': rdt.transformers.NumericalTransformer(
-                    dtype=np.int64,
-                    nan='mean' if self._null_column else None,
-                    null_column=transformer_null_column,
-                    min_value='auto',
-                    max_value='auto',
+                'i': rdt.transformers.FloatFormatter(
+                    missing_value_replacement='mean',
+                    model_missing_values=transformer_model_missing_values,
+                    enforce_min_max_values=True,
                 ),
-                'f': rdt.transformers.NumericalTransformer(
-                    dtype=np.float64,
-                    nan='mean' if self._null_column else None,
-                    null_column=transformer_null_column,
-                    min_value='auto',
-                    max_value='auto',
+                'f': rdt.transformers.FloatFormatter(
+                    missing_value_replacement='mean',
+                    model_missing_values=transformer_model_missing_values,
+                    enforce_min_max_values=True,
                 ),
-                'O': rdt.transformers.CategoricalTransformer(fuzzy=True),
-                'b': rdt.transformers.BooleanTransformer(
-                    nan=-1 if self._null_column else None,
-                    null_column=transformer_null_column,
+                'O': rdt.transformers.FrequencyEncoder(add_noise=True),
+                'b': rdt.transformers.BinaryEncoder(
+                    missing_value_replacement=-1 if self._null_column else 'mode',
+                    model_missing_values=transformer_model_missing_values,
                 ),
-                'M': rdt.transformers.DatetimeTransformer(
-                    nan='mean' if self._null_column else None,
-                    null_column=transformer_null_column,
+                'M': rdt.transformers.UnixTimestampEncoder(
+                    missing_value_replacement='mean' if self._null_column else 'mode',
+                    model_missing_values=transformer_model_missing_values,
                 ),
             }
             self._model._metadata._dtype_transformers.update(dtype_transformers)
@@ -142,8 +140,8 @@ class TabularPreset():
 
         return sampled
 
-    def sample(self, num_rows, randomize_samples=True, batch_size=None, output_file_path=None,
-               conditions=None):
+    def sample(self, num_rows, randomize_samples=True, max_tries_per_batch=100,
+               batch_size=None, output_file_path=None, conditions=None):
         """Sample rows from this table.
 
         Args:
@@ -152,6 +150,8 @@ class TabularPreset():
             randomize_samples (bool):
                 Whether or not to use a fixed seed when sampling. Defaults
                 to True.
+            max_tries_per_batch (int):
+                Number of times to try sampling discarded rows. Defaults to 100.
             batch_size (int or None):
                 The batch size to sample. Defaults to `num_rows`, if None.
             output_file_path (str or None):
@@ -166,11 +166,13 @@ class TabularPreset():
                 Sampled data.
         """
         sampled = self._model.sample(
-            num_rows, randomize_samples, batch_size, output_file_path, conditions)
+            num_rows, randomize_samples, max_tries_per_batch,
+            batch_size, output_file_path, conditions
+        )
 
         return self._postprocess_sampled(sampled)
 
-    def sample_conditions(self, conditions, max_tries=100, batch_size_per_try=None,
+    def sample_conditions(self, conditions, max_tries_per_batch=100, batch_size=None,
                           randomize_samples=True, output_file_path=None):
         """Sample rows from this table with the given conditions.
 
@@ -179,9 +181,9 @@ class TabularPreset():
                 A list of sdv.sampling.Condition objects, which specify the column
                 values in a condition, along with the number of rows for that
                 condition.
-            max_tries (int):
+            max_tries_per_batch (int):
                 Number of times to try sampling discarded rows. Defaults to 100.
-            batch_size_per_try (int):
+            batch_size (int):
                 The batch size to use per attempt at sampling. Defaults to 10 times
                 the number of rows.
             randomize_samples (bool):
@@ -196,11 +198,11 @@ class TabularPreset():
                 Sampled data.
         """
         sampled = self._model.sample_conditions(
-            conditions, max_tries, batch_size_per_try, randomize_samples, output_file_path)
+            conditions, max_tries_per_batch, batch_size, randomize_samples, output_file_path)
 
         return self._postprocess_sampled(sampled)
 
-    def sample_remaining_columns(self, known_columns, max_tries=100, batch_size_per_try=None,
+    def sample_remaining_columns(self, known_columns, max_tries_per_batch=100, batch_size=None,
                                  randomize_samples=True, output_file_path=None):
         """Sample rows from this table.
 
@@ -209,9 +211,9 @@ class TabularPreset():
                 A pandas.DataFrame with the columns that are already known. The output
                 is a DataFrame such that each row in the output is sampled
                 conditionally on the corresponding row in the input.
-            max_tries (int):
+            max_tries_per_batch (int):
                 Number of times to try sampling discarded rows. Defaults to 100.
-            batch_size_per_try (int):
+            batch_size (int):
                 The batch size to use per attempt at sampling. Defaults to 10 times
                 the number of rows.
             randomize_samples (bool):
@@ -226,18 +228,21 @@ class TabularPreset():
                 Sampled data.
         """
         sampled = self._model.sample_remaining_columns(
-            known_columns, max_tries, batch_size_per_try, randomize_samples, output_file_path)
+            known_columns, max_tries_per_batch, batch_size, randomize_samples, output_file_path)
 
         return self._postprocess_sampled(sampled)
 
     def save(self, path):
-        """Save this model instance to the given path using pickle.
+        """Save this model instance to the given path using cloudpickle.
 
         Args:
             path (str):
                 Path where the SDV instance will be serialized.
         """
-        self._model.save(path)
+        self._package_versions = get_package_versions(getattr(self, '_model', None))
+
+        with open(path, 'wb') as output:
+            cloudpickle.dump(self, output)
 
     @classmethod
     def load(cls, path):
@@ -251,7 +256,11 @@ class TabularPreset():
             TabularModel:
                 The loaded tabular model.
         """
-        return cls._default_model.load(path)
+        with open(path, 'rb') as f:
+            model = cloudpickle.load(f)
+            throw_version_mismatch_warning(getattr(model, '_package_versions', None))
+
+            return model
 
     @classmethod
     def list_available_presets(cls, out=sys.stdout):
