@@ -1,6 +1,7 @@
 """Wrappers around copulas models."""
 
 import logging
+import warnings
 
 import copulas
 import copulas.multivariate
@@ -33,14 +34,14 @@ class GaussianCopula(BaseTabularModel):
             Dictinary specifying which transformers to use for each field.
             Available transformers are:
 
-                * ``integer``: Uses a ``NumericalTransformer`` of dtype ``int``.
-                * ``float``: Uses a ``NumericalTransformer`` of dtype ``float``.
-                * ``categorical``: Uses a ``CategoricalTransformer`` without gaussian noise.
-                * ``categorical_fuzzy``: Uses a ``CategoricalTransformer`` adding gaussian noise.
-                * ``one_hot_encoding``: Uses a ``OneHotEncodingTransformer``.
-                * ``label_encoding``: Uses a ``LabelEncodingTransformer``.
-                * ``boolean``: Uses a ``BooleanTransformer``.
-                * ``datetime``: Uses a ``DatetimeTransformer``.
+                * ``FloatFormatter``: Uses a ``FloatFormatter`` for numerical data.
+                * ``FrequencyEncoder``: Uses a ``FrequencyEncoder`` without gaussian noise.
+                * ``FrequencyEncoder_noised``: Uses a ``FrequencyEncoder`` adding gaussian noise.
+                * ``OneHotEncoder``: Uses a ``OneHotEncoder``.
+                * ``LabelEncoder``: Uses a ``LabelEncoder`` without gaussian nose.
+                * ``LabelEncoder_noised``: Uses a ``LabelEncoder`` adding gaussian noise.
+                * ``BinaryEncoder``: Uses a ``BinaryEncoder``.
+                * ``UnixTimestampEncoder``: Uses a ``UnixTimestampEncoder``.
 
         anonymize_fields (dict[str, str]):
             Dict specifying which fields to anonymize and what faker
@@ -60,22 +61,6 @@ class GaussianCopula(BaseTabularModel):
             the distribution that needs to be used. The distributions can be passed as either
             a ``copulas.univariate`` instance or as one of the following values:
 
-                * ``univariate``: Let ``copulas`` select the optimal univariate distribution.
-                  This may result in non-parametric models being used.
-                * ``parametric``: Let ``copulas`` select the optimal univariate distribution,
-                  but restrict the selection to parametric distributions only.
-                * ``bounded``: Let ``copulas`` select the optimal univariate distribution,
-                  but restrict the selection to bounded distributions only.
-                  This may result in non-parametric models being used.
-                * ``semi_bounded``: Let ``copulas`` select the optimal univariate distribution,
-                  but restrict the selection to semi-bounded distributions only.
-                  This may result in non-parametric models being used.
-                * ``parametric_bounded``: Let ``copulas`` select the optimal univariate
-                  distribution, but restrict the selection to parametric and bounded distributions
-                  only.
-                * ``parametric_semi_bounded``: Let ``copulas`` select the optimal univariate
-                  distribution, but restrict the selection to parametric and semi-bounded
-                  distributions only.
                 * ``gaussian``: Use a Gaussian distribution.
                 * ``gamma``: Use a Gamma distribution.
                 * ``beta``: Use a Beta distribution.
@@ -86,40 +71,36 @@ class GaussianCopula(BaseTabularModel):
 
         default_distribution (copulas.univariate.Univariate or str):
             Copulas univariate distribution to use by default. To choose from the list
-            of possible ``field_distribution`` values. Defaults to ``parametric``.
+            of possible ``field_distribution`` values.
+            Defaults to ``truncated_gaussian``.
         categorical_transformer (str):
             Type of transformer to use for the categorical variables, which must be one of the
             following values:
 
-                * ``one_hot_encoding``: Apply a OneHotEncodingTransformer to the
+                * ``OneHotEncoder``: Apply a ``OneHotEncoder`` to the
                   categorical column, which replaces the  column with one boolean
                   column for each possible category, indicating whether each row
                   had that value or not.
-                * ``label_encoding``: Apply a LabelEncodingTransformer, which
+                * ``LabelEncoder``: Apply a ``LabelEncoder``, which
                   replaces the value of each category with an integer value that
                   acts as its *label*.
-                * ``categorical``: Apply CategoricalTransformer, which replaces
+                * ``LabelEncoder_noised``: Apply a ``LabelEncoder``, which
+                  replaces the value of each category with an integer value that
+                  acts as its *label*.
+                * ``FrequencyEncoder``: Apply ``FrequencyEncoder``, which replaces
                   each categorical value with a float number in the `[0, 1]` range
                   which is inversely proportional to the frequency of that category.
-                * ``categorical_fuzzy``: Apply a CategoricalTransformer with the
-                  ``fuzzy`` argument set to ``True``, which makes it add gaussian
+                * ``FrequencyEncoder_noised``: Apply a ``FrequencyEncoder`` with the
+                  ``add_noise`` argument set to ``True``, which makes it add gaussian
                   noise around each value.
-            Defaults to ``categorical_fuzzy``.
-        rounding (int, str or None):
-            Define rounding scheme for ``NumericalTransformer``. If set to an int, values
-            will be rounded to that number of decimal places. If ``None``, values will not
-            be rounded. If set to ``'auto'``, the transformer will round to the maximum number
-            of decimal places detected in the fitted data. Defaults to ``'auto'``.
-        min_value (int, str or None):
-            Specify the minimum value the ``NumericalTransformer`` should use. If an integer
-            is given, sampled data will be greater than or equal to it. If the string ``'auto'``
-            is given, the minimum will be the minimum value seen in the fitted data. If ``None``
-            is given, there won't be a minimum. Defaults to ``'auto'``.
-        max_value (int, str or None):
-            Specify the maximum value the ``NumericalTransformer`` should use. If an integer
-            is given, sampled data will be less than or equal to it. If the string ``'auto'``
-            is given, the maximum will be the maximum value seen in the fitted data. If ``None``
-            is given, there won't be a maximum. Defaults to ``'auto'``.
+            Defaults to ``FrequencyEncoder_noised``.
+        learn_rounding_scheme (bool):
+            Define rounding scheme for ``FloatFormatter``. If ``True``, the data returned by
+            ``reverse_transform`` will be rounded to that place. Defaults to ``True``.
+        enforce_min_max_values (bool):
+            Specify whether or not to clip the data returned by ``reverse_transform`` of
+            the numerical transformer, ``FloatFormatter``, to the min and max values seen
+            during ``fit``. Defaults to ``True``.
     """
 
     _field_distributions = None
@@ -128,21 +109,6 @@ class GaussianCopula(BaseTabularModel):
     _model = None
 
     _DISTRIBUTIONS = {
-        'univariate': copulas.univariate.Univariate,
-        'parametric': copulas.univariate.Univariate(
-            parametric=copulas.univariate.ParametricType.PARAMETRIC),
-        'bounded': copulas.univariate.Univariate(
-            bounded=copulas.univariate.BoundedType.BOUNDED),
-        'semi_bounded': copulas.univariate.Univariate(
-            bounded=copulas.univariate.BoundedType.SEMI_BOUNDED),
-        'parametric_bounded': copulas.univariate.Univariate(
-            parametric=copulas.univariate.ParametricType.PARAMETRIC,
-            bounded=copulas.univariate.BoundedType.BOUNDED,
-        ),
-        'parametric_semi_bounded': copulas.univariate.Univariate(
-            parametric=copulas.univariate.ParametricType.PARAMETRIC,
-            bounded=copulas.univariate.BoundedType.SEMI_BOUNDED,
-        ),
         'gaussian': copulas.univariate.GaussianUnivariate,
         'gamma': copulas.univariate.GammaUnivariate,
         'beta': copulas.univariate.BetaUnivariate,
@@ -150,8 +116,8 @@ class GaussianCopula(BaseTabularModel):
         'gaussian_kde': copulas.univariate.GaussianKDE,
         'truncated_gaussian': copulas.univariate.TruncatedGaussian,
     }
-    _DEFAULT_DISTRIBUTION = _DISTRIBUTIONS['parametric']
-    _DEFAULT_TRANSFORMER = 'categorical_fuzzy'
+    _DEFAULT_DISTRIBUTION = _DISTRIBUTIONS['truncated_gaussian']
+    _DEFAULT_TRANSFORMER = 'FrequencyEncoder_noised'
 
     @classmethod
     def _validate_distribution(cls, distribution):
@@ -170,8 +136,8 @@ class GaussianCopula(BaseTabularModel):
     def __init__(self, field_names=None, field_types=None, field_transformers=None,
                  anonymize_fields=None, primary_key=None, constraints=None, table_metadata=None,
                  field_distributions=None, default_distribution=None,
-                 categorical_transformer=None, rounding='auto', min_value='auto',
-                 max_value='auto'):
+                 categorical_transformer=None, learn_rounding_scheme=True,
+                 enforce_min_max_values=True):
 
         if isinstance(table_metadata, dict):
             table_metadata = Table.from_dict(table_metadata)
@@ -210,9 +176,8 @@ class GaussianCopula(BaseTabularModel):
             primary_key=primary_key,
             constraints=constraints,
             table_metadata=table_metadata,
-            rounding=rounding,
-            max_value=max_value,
-            min_value=min_value
+            learn_rounding_scheme=learn_rounding_scheme,
+            enforce_min_max_values=enforce_min_max_values
         )
 
         self._metadata.set_model_kwargs(self.__class__.__name__, {
@@ -264,84 +229,21 @@ class GaussianCopula(BaseTabularModel):
         for column in table_data.columns:
             if column not in self._field_distributions:
                 # Check if the column is a derived column.
-                column_name = column.replace('.value', '')
                 self._field_distributions[column] = self._field_distributions.get(
-                    column_name, self._default_distribution)
+                    column, self._default_distribution)
 
         self._model = copulas.multivariate.GaussianMultivariate(
             distribution=self._field_distributions)
 
         LOGGER.debug('Fitting %s to table %s; shape: %s', self._model.__class__.__name__,
                      self._metadata.name, table_data.shape)
-        self._model.fit(table_data)
+
+        with warnings.catch_warnings():
+            warnings.filterwarnings('ignore', module='scipy')
+            self._model.fit(table_data)
+
         self._update_metadata()
 
-    def sample_conditions(self, conditions, batch_size=None, randomize_samples=True,
-                          output_file_path=None):
-        """Sample rows from this table with the given conditions.
-
-        Args:
-            conditions (list[sdv.sampling.Condition]):
-                A list of sdv.sampling.Condition objects, which specify the column
-                values in a condition, along with the number of rows for that
-                condition.
-            batch_size (int or None):
-                The batch size to sample. Defaults to `num_rows`, if None.
-            randomize_samples (bool):
-                Whether or not to use a fixed seed when sampling. Defaults
-                to True.
-            output_file_path (str or None):
-                The file to periodically write sampled rows to. Defaults to
-                a temporary file, if None.
-
-        Returns:
-            pandas.DataFrame:
-                Sampled data.
-
-        Raises:
-            ConstraintsNotMetError:
-                If the conditions are not valid for the given constraints.
-            ValueError:
-                If any of the following happens:
-                    * any of the conditions' columns are not valid.
-                    * no rows could be generated.
-        """
-        return self._sample_conditions(
-            conditions, 100, batch_size, randomize_samples, output_file_path)
-
-    def sample_remaining_columns(self, known_columns, batch_size=None, randomize_samples=True,
-                                 output_file_path=None):
-        """Sample rows from this table.
-
-        Args:
-            known_columns (pandas.DataFrame):
-                A pandas.DataFrame with the columns that are already known. The output
-                is a DataFrame such that each row in the output is sampled
-                conditionally on the corresponding row in the input.
-            batch_size (int or None):
-                The batch size to sample. Defaults to `num_rows`, if None.
-            randomize_samples (bool):
-                Whether or not to use a fixed seed when sampling. Defaults
-                to True.
-            output_file_path (str or None):
-                The file to periodically write sampled rows to. Defaults to
-                a temporary file, if None.
-
-        Returns:
-            pandas.DataFrame:
-                Sampled data.
-
-        Raises:
-            ConstraintsNotMetError:
-                If the conditions are not valid for the given constraints.
-            ValueError:
-                If any of the following happens:
-                    * any of the conditions' columns are not valid.
-                    * no rows could be generated.
-        """
-        return self._sample_remaining_columns(
-            known_columns, 100, batch_size, randomize_samples, output_file_path)
-
     def _sample(self, num_rows, conditions=None):
         """Sample the indicated number of rows from the model.
 
