@@ -4,8 +4,7 @@ import pandas as pd
 import pytest
 from copulas.multivariate.gaussian import GaussianMultivariate
 
-from sdv.constraints import Unique, UniqueCombinations
-from sdv.constraints.tabular import GreaterThan
+from sdv.constraints import FixedCombinations, Unique
 from sdv.demo import load_tabular_demo
 from sdv.sampling import Condition
 from sdv.tabular.copulagan import CopulaGAN
@@ -44,11 +43,11 @@ def test___init___copies_metadata():
 
     # Run
     model = GaussianCopula(table_metadata=metadata,
-                           categorical_transformer='label_encoding',
+                           categorical_transformer='LabelEncoder',
                            default_distribution='gamma')
     model.fit(data)
     model2 = GaussianCopula(table_metadata=metadata,
-                            categorical_transformer='label_encoding',
+                            categorical_transformer='LabelEncoder',
                             default_distribution='beta')
     model2.fit(data)
 
@@ -134,7 +133,7 @@ def test_fit_with_unique_constraint_on_data_with_only_index_column():
             "E",
         ]
     })
-    unique = Unique(columns=["index"])
+    unique = Unique(column_names=["index"])
     model = GaussianCopula(primary_key="key", constraints=[unique])
 
     # Run
@@ -188,7 +187,7 @@ def test_fit_with_unique_constraint_on_data_which_has_index_column():
             "E5",
         ]
     })
-    unique = Unique(columns=["test_column"])
+    unique = Unique(column_names=["test_column"])
     model = GaussianCopula(primary_key="key", constraints=[unique])
 
     # Run
@@ -236,7 +235,7 @@ def test_fit_with_unique_constraint_on_data_subset():
         ]
     })
     unique = Unique(
-        columns=["test_column"]
+        column_names=["test_column"]
     )
 
     test_df = test_df.iloc[[1, 3, 4]]
@@ -259,8 +258,7 @@ def test_conditional_sampling_constraint_uses_reject_sampling(gm_mock, isinstanc
 
     The ``sample`` method is expected to properly apply constraint
     transformations by dropping columns that cannot be conditonally sampled
-    on due to them being part of a constraint if ``fit_columns_model``
-    is False.
+    on due to them being part of a constraint.
 
     Setup:
     - The model is being passed a ``UniqueCombination`` constraint and then
@@ -276,23 +274,19 @@ def test_conditional_sampling_constraint_uses_reject_sampling(gm_mock, isinstanc
     """
     # Setup
     isinstance_mock.side_effect = _isinstance_side_effect
-    constraint = UniqueCombinations(
-        columns=['city', 'state'],
-        handling_strategy='transform',
-        fit_columns_model=False
-    )
+    constraint = FixedCombinations(column_names=['city', 'state'])
     data = pd.DataFrame({
         'city': ['LA', 'SF', 'CHI', 'LA', 'LA'],
         'state': ['CA', 'CA', 'IL', 'CA', 'CA'],
         'age': [27, 28, 26, 21, 30]
     })
-    model = GaussianCopula(constraints=[constraint], categorical_transformer='label_encoding')
+    model = GaussianCopula(constraints=[constraint], categorical_transformer='LabelEncoder')
     sampled_numeric_data = [pd.DataFrame({
-        'city#state.value': [0, 1, 2, 0, 0],
-        'age.value': [30, 30, 30, 30, 30]
+        'city#state': [0, 1, 2, 0, 0],
+        'age': [30, 30, 30, 30, 30]
     }), pd.DataFrame({
-        'city#state.value': [1],
-        'age.value': [30]
+        'city#state': [1],
+        'age': [30]
     })]
     gm_mock.return_value.sample.side_effect = sampled_numeric_data
     model.fit(data)
@@ -302,7 +296,7 @@ def test_conditional_sampling_constraint_uses_reject_sampling(gm_mock, isinstanc
     sampled_data = model.sample_conditions(conditions=conditions)
 
     # Assert
-    expected_transformed_conditions = {'age.value': 30}
+    expected_transformed_conditions = {'age': 30}
     expected_data = pd.DataFrame({
         'city': ['LA', 'SF', 'LA', 'LA', 'SF'],
         'state': ['CA', 'CA', 'CA', 'CA', 'CA'],
@@ -310,143 +304,43 @@ def test_conditional_sampling_constraint_uses_reject_sampling(gm_mock, isinstanc
     })
     sample_calls = model._model.sample.mock_calls
     assert len(sample_calls) == 2
-    model._model.sample.assert_any_call(50, conditions=expected_transformed_conditions)
+    model._model.sample.assert_any_call(5, conditions=expected_transformed_conditions)
     pd.testing.assert_frame_equal(sampled_data, expected_data)
 
 
-@patch('sdv.tabular.base.isinstance')
-@patch('sdv.tabular.copulas.copulas.multivariate.GaussianMultivariate',
-       spec_set=GaussianMultivariate)
-def test_conditional_sampling_constraint_uses_columns_model(gm_mock, isinstance_mock):
-    """Test that the ``sample`` method handles constraints with conditions.
+def test_sample_conditions_with_batch_size():
+    """Test the ``sample_conditions`` method with a different ``batch_size``.
 
-    The ``sample`` method is expected to properly apply constraint
-    transformations by sampling the missing columns for the constraint
-    if ``fit_columns_model`` is True.
+    If a smaller ``batch_size`` is passed, then the conditions should be broken down into
+    batches of that size. If the ``batch_size`` is larger than the condition length, then
+    the condition length should be used.
 
-    Setup:
-    - The model is being passed a ``UniqueCombination`` constraint and then
-    asked to sample with two conditions, one of which the constraint depends on.
-    The constraint will sample the columns it needs that are not present in
-    the conditions and will then use constraint transformations to meet the
-    requirements.
+    - Input:
+        - Conditions one of length 100 and another of length 10
+        - Batch size of length 50
 
-    Input:
-    - Conditions
-    Side Effects:
-    - Correct columns to condition on are passed to underlying sample method
+    - Output:
+        - Sampled data
     """
     # Setup
-    isinstance_mock.side_effect = _isinstance_side_effect
-    constraint = UniqueCombinations(
-        columns=['city', 'state'],
-        handling_strategy='transform',
-        fit_columns_model=True,
-    )
+    model = GaussianCopula()
     data = pd.DataFrame({
-        'city': ['LA', 'SF', 'CHI', 'LA', 'LA'],
-        'state': ['CA', 'CA', 'IL', 'CA', 'CA'],
-        'age': [27, 28, 26, 21, 30]
+        'column1': list(range(100)),
+        'column2': list(range(100)),
+        'column3': list(range(100))
     })
-    model = GaussianCopula(constraints=[constraint], categorical_transformer='label_encoding')
-    sampled_numeric_data = [pd.DataFrame({
-        'city#state.value': [2],
-        'age.value': [30]
-    }), pd.DataFrame({
-        'city#state.value': [1, 1, 0, 0, 0],
-        'age.value': [30, 30, 30, 30, 30]
-    }), pd.DataFrame({
-        'city#state.value': [0, 0, 1, 1, 1],
-        'age.value': [30, 30, 30, 30, 30]})
-    ]
-    gm_mock.return_value.sample.side_effect = sampled_numeric_data
     model.fit(data)
-
-    # Run
-    conditions = [Condition({'age': 30, 'state': 'CA'}, num_rows=5)]
-    sampled_data = model.sample_conditions(conditions=conditions)
-
-    # Assert
-    expected_states = pd.Series(['CA', 'CA', 'CA', 'CA', 'CA'], name='state')
-    expected_ages = pd.Series([30, 30, 30, 30, 30], name='age')
-    sample_calls = model._model.sample.mock_calls
-    assert len(sample_calls) >= 2 and len(sample_calls) <= 3
-    assert all(c[2]['conditions']['age.value'] == 30 for c in sample_calls)
-    assert all('city#state.value' in c[2]['conditions'] for c in sample_calls)
-    pd.testing.assert_series_equal(sampled_data['age'], expected_ages)
-    pd.testing.assert_series_equal(sampled_data['state'], expected_states)
-    assert all(c in ('SF', 'LA') for c in sampled_data['city'])
-
-
-@patch('sdv.constraints.base.GaussianMultivariate',
-       spec_set=GaussianMultivariate)
-def test_conditional_sampling_constraint_uses_columns_model_reject_sampling(column_model_mock):
-    """Test that the ``sample`` method handles constraints with conditions.
-
-    The ``sample`` method is expected to properly apply constraint
-    transformations by sampling the missing columns for the constraint
-    if ``fit_columns_model`` is True. All values sampled by the column
-    model should be valid because reject sampling is used on any that aren't.
-
-    Setup:
-    - The model is being passed a ``GreaterThan`` constraint and then
-    asked to sample with one condition. One of the constraint columns is
-    the conditioned column. The ``GaussianMultivariate`` class is mocked
-    so that the constraint's ``_column_model`` returns some invalid rows
-    in order to test that the reject sampling is used.
-
-    Input:
-    - Conditions
-    Side Effects:
-    - Correct columns to condition on are passed to underlying sample method
-    """
-    # Setup
-    constraint = GreaterThan(
-        low='age_joined',
-        high='age',
-        handling_strategy='transform',
-        fit_columns_model=True,
-        drop='high'
-    )
-    data = pd.DataFrame({
-        'age_joined': [22.0, 21.0, 15.0, 18.0, 29.0],
-        'age': [27.0, 28.0, 26.0, 21.0, 30.0],
-        'experience_years': [6.0, 7.0, 11.0, 3.0, 7.0],
-    })
-    model = GaussianCopula(constraints=[constraint])
-    sampled_conditions = [
-        pd.DataFrame({
-            'age_joined.value': [26.0, 18.0, 31.0, 29.0, 32.0],
-            'age.value': [30.0, 30.0, 30.0, 30.0, 30.0]
-        }),
-        pd.DataFrame({
-            'age_joined.value': [28.0, 33.0, 31.0],
-            'age.value': [30.0, 30.0, 30.0]
-        }),
-        pd.DataFrame({
-            'age_joined.value': [27.0],
-            'age.value': [30.0]
-        })
+    conditions = [
+        Condition({'column1': 10}, num_rows=100),
+        Condition({'column1': 50}, num_rows=10)
     ]
 
-    column_model_mock.return_value.sample.side_effect = sampled_conditions
-    model.fit(data)
-
     # Run
-    conditions = [Condition({'age': 30.0}, num_rows=5)]
-    sampled_data = model.sample_conditions(conditions=conditions)
+    sampled_data = model.sample_conditions(conditions, batch_size=50)
 
     # Assert
-    assert len(column_model_mock.return_value.sample.mock_calls) == 3
-
-    expected_result = pd.DataFrame({
-        'age_joined': [26.0, 18.0, 29.0, 28.0, 27.0],
-        'age': [30.0, 30.0, 30.0, 30.0, 30.0]
-    })
-    pd.testing.assert_frame_equal(
-        sampled_data[['age_joined', 'age']],
-        expected_result[['age_joined', 'age']],
-    )
+    expected = pd.Series([10] * 100 + [50] * 10, name='column1')
+    pd.testing.assert_series_equal(sampled_data['column1'], expected)
 
 
 @pytest.mark.parametrize('model', MODELS)
