@@ -1,6 +1,6 @@
 import os
 from unittest import TestCase
-from unittest.mock import Mock, call, patch
+from unittest.mock import Mock, patch
 
 import pandas as pd
 import pytest
@@ -229,7 +229,6 @@ class TestMetadata(TestCase):
         mock_meta.assert_called_once_with({'some': 'meta'})
         mock_relationships.assert_called_once_with()
         assert metadata.root_path == '.'
-        assert metadata._hyper_transformers == dict()
 
     def test_get_children(self):
         """Test get children"""
@@ -409,127 +408,6 @@ class TestMetadata(TestCase):
 
         assert len(errors) == 1
 
-    def test__get_pii_fields(self):
-        """Test get pii fields"""
-        # Setup
-        table_meta = {
-            'fields': {
-                'foo': {
-                    'type': 'categorical',
-                    'pii': True,
-                    'pii_category': 'email'
-                },
-                'bar': {
-                    'type': 'categorical',
-                    'pii_category': 'email'
-                }
-            }
-        }
-        metadata = Mock(spec_set=Metadata)
-        metadata.get_table_meta.return_value = table_meta
-
-        # Run
-        result = Metadata._get_pii_fields(metadata, 'test')
-
-        # Asserts
-        assert result == {'foo': 'email'}
-
-    @patch('sdv.metadata.dataset.transformers.DatetimeTransformer')
-    @patch('sdv.metadata.dataset.transformers.BooleanTransformer')
-    @patch('sdv.metadata.dataset.transformers.CategoricalTransformer')
-    @patch('sdv.metadata.dataset.transformers.NumericalTransformer')
-    def test__get_transformers_no_error(self, numerical_mock, categorical_mock,
-                                        boolean_mock, datetime_mock):
-        """Test get transformers dict for each data type."""
-        # Setup
-        numerical_mock.return_value = 'NumericalTransformer'
-        categorical_mock.return_value = 'CategoricalTransformer'
-        boolean_mock.return_value = 'BooleanTransformer'
-        datetime_mock.return_value = 'DatetimeTransformer'
-
-        # Run
-        dtypes = {
-            'integer': 'int',
-            'float': 'float',
-            'categorical': 'object',
-            'boolean': 'bool',
-            'datetime': 'datetime64'
-        }
-        pii_fields = {
-            'categorical': 'email'
-        }
-        result = Metadata._get_transformers(dtypes, pii_fields)
-
-        # Asserts
-        expected = {
-            'integer': 'NumericalTransformer',
-            'float': 'NumericalTransformer',
-            'categorical': 'CategoricalTransformer',
-            'boolean': 'BooleanTransformer',
-            'datetime': 'DatetimeTransformer'
-        }
-        expected_numerical_calls = [call(dtype=int), call(dtype=float)]
-
-        assert result == expected
-        assert len(numerical_mock.call_args_list) == len(expected_numerical_calls)
-        for item in numerical_mock.call_args_list:
-            assert item in expected_numerical_calls
-
-        assert categorical_mock.call_args == call(anonymize='email')
-        assert boolean_mock.call_args == call()
-        assert datetime_mock.call_args == call()
-
-    def test__get_transformers_raise_valueerror(self):
-        """Test get transformers dict raise ValueError."""
-        # Run
-        dtypes = {
-            'void': 'void'
-        }
-        with pytest.raises(ValueError):
-            Metadata._get_transformers(dtypes, None)
-
-    @patch('sdv.metadata.dataset.HyperTransformer')
-    def test__load_hyper_transformer(self, mock_ht):
-        """Test load HyperTransformer"""
-        # Setup
-        metadata = Mock(spec_set=Metadata)
-        metadata.get_dtypes.return_value = {'meta': 'dtypes'}
-        metadata._get_pii_fields.return_value = {'meta': 'pii_fields'}
-        metadata._get_transformers.return_value = {'meta': 'transformers'}
-        mock_ht.return_value = 'hypertransformer'
-
-        # Run
-        result = Metadata._load_hyper_transformer(metadata, 'test')
-
-        # Asserts
-        assert result == 'hypertransformer'
-        metadata.get_dtypes.assert_called_once_with('test')
-        metadata._get_pii_fields.assert_called_once_with('test')
-        metadata._get_transformers.assert_called_once_with(
-            {'meta': 'dtypes'},
-            {'meta': 'pii_fields'}
-        )
-        mock_ht.assert_called_once_with(field_transformers={'meta': 'transformers'})
-
-    def test_get_tables(self):
-        """Test get table names"""
-        # Setup
-        _metadata = {
-            'tables': {
-                'table 1': None,
-                'table 2': None,
-                'table 3': None
-            }
-        }
-        metadata = Mock(spec_set=Metadata)
-        metadata._metadata = _metadata
-
-        # Run
-        result = Metadata.get_tables(metadata)
-
-        # Asserts
-        assert sorted(result) == ['table 1', 'table 2', 'table 3']
-
     def test_load_tables(self):
         """Test get tables"""
         # Setup
@@ -635,39 +513,6 @@ class TestMetadata(TestCase):
         # Asserts
         assert result == ['parent_id', 'parent_id_2']
 
-    def test_reverse_transform(self):
-        """Test reverse transform"""
-        # Setup
-        ht_mock = Mock()
-        ht_mock.reverse_transform.return_value = {
-            'item 1': pd.Series([1.0, 2.0, None, 4.0, 5.0]),
-            'item 2': pd.Series([1.1, None, 3.3, None, 5.5]),
-            'item 3': pd.Series([None, 'bbb', 'ccc', 'ddd', None]),
-            'item 4': pd.Series([True, False, None, False, True])
-        }
-
-        metadata = Mock(spec_set=Metadata)
-        metadata._hyper_transformers = {
-            'test': ht_mock
-        }
-        metadata.get_dtypes.return_value = {
-            'item 1': 'int',
-            'item 2': 'float',
-            'item 3': 'str',
-            'item 4': 'bool',
-        }
-
-        # Run
-        data = pd.DataFrame({'foo': [0, 1]})
-        Metadata.reverse_transform(metadata, 'test', data)
-
-        # Asserts
-        expected_call = pd.DataFrame({'foo': [0, 1]})
-        pd.testing.assert_frame_equal(
-            ht_mock.reverse_transform.call_args[0][0],
-            expected_call
-        )
-
     def test_add_table_already_exist(self):
         """Try to add a new table that already exist"""
         # Setup
@@ -892,7 +737,7 @@ class TestMetadata(TestCase):
         - Constraints for the given table
         Side Effects:
         - An entry is added to the metadata for the provided table, which contains
-          the given fields and constrants.
+          the given fields and constraints.
         """
         # Setup
         metadata = Mock(spec_set=Metadata)
@@ -906,12 +751,11 @@ class TestMetadata(TestCase):
         }
         constraints = [
             {
-                'constraint': 'sdv.constraints.tabular.GreaterThan',
+                'constraint': 'sdv.constraints.tabular.Inequality',
                 'columns': [
                     'a_field',
                     'b_field',
                 ],
-                'handling_strategy': 'transform',
             }
         ]
 
@@ -930,12 +774,11 @@ class TestMetadata(TestCase):
             },
             'constraints': [
                 {
-                    'constraint': 'sdv.constraints.tabular.GreaterThan',
+                    'constraint': 'sdv.constraints.tabular.Inequality',
                     'columns': [
                         'a_field',
                         'b_field',
                     ],
-                    'handling_strategy': 'transform',
                 },
             ]
         }
